@@ -56,12 +56,8 @@ if [ `hal-get-property --udi /org/freedesktop/Hal/devices/platform_kb_lock --key
 		echo "`/usr/sbin/kernel-config show | grep "max" | sed 's/. frequency//g'`" > /tmp/savepress-value
 		echo "`/usr/sbin/kernel-config show | grep "min" | sed 's/. frequency//g'`" >> /tmp/savepress-value
 		if [ "`cat /home/user/.config/savepress | grep "vwlan" | sed 's/vwlan: //g' | sed 's/ //g'`" == "True" ]; then {
-			ip="`/sbin/ifconfig wlan0 | grep "inet addr" | awk -F: '{print $2}' | awk '{print $1}'`"
-			if [ "$ip" != "" ]; then {
-				dbus-send --system --dest=com.nokia.icd /com/nokia/icd_ui com.nokia.icd_ui.disconnect boolean:true
-				echo "wlan-dis" >> /tmp/savepress-value
-				}
-			fi
+			dbus-send --system --dest=com.nokia.icd /com/nokia/icd_ui com.nokia.icd_ui.disconnect boolean:true
+			echo "wlan-dis" >> /tmp/savepress-value
 			}
 		fi
 		
